@@ -21,14 +21,17 @@ test_that("function bootspat_naive works", {
   rand.both2 <- bootspat_naive(bin1, "both", memory = F)
 
   # testing
-  expect_true(class(rand.site) == "SpatRaster", "TRUE")
-  expect_true(class(rand.sp) == "SpatRaster", "TRUE")
-  expect_true(class(rand.both) == "SpatRaster", "TRUE")
+  expect_true(inherits(rand.site, "SpatRaster"), "TRUE")
+  expect_true(inherits(rand.sp, "SpatRaster"), "TRUE")
+  expect_true(inherits(rand.both, "SpatRaster"), "TRUE")
 
+  expect_equal(unlist(rand.site[2]), setNames(rep(0, terra::nlyr(bin1)), names(bin1)))
+  expect_equal(unlist(rand.sp[2]), setNames(c(0,0,0,0,1,0,1), names(bin1)))
+  expect_equal(unlist(rand.both[2]), setNames(c(0,1,1,0,0,1,1), names(bin1)))
 
-  expect_equal(unlist(rand.site[2]), setNames(c(0,0,1,0,1), names(bin1)))
+  expect_equal(unlist(rand.site[1]), setNames(as.double(rep(NA, terra::nlyr(bin1))), names(bin1)))
+  expect_equal(unlist(rand.sp[1]), setNames(as.double(rep(NA, terra::nlyr(bin1))), names(bin1)))
+  expect_equal(unlist(rand.both[1]), setNames(as.double(rep(NA, terra::nlyr(bin1))), names(bin1)))
 
-  expect_equal(unlist(rand.sp[2]), setNames(c(0,1,1,0,0), names(bin1)))
-
-  expect_equal(unlist(rand.both[2]), setNames(c(1,0,0,0,1), names(bin1)))
+  expect_equal(sum(rand.site)[1:8], sum(bin1)[1:8]) # test richness
 })
